@@ -29,7 +29,13 @@ try:
 except ImportError:
     request_imported = False
 
-from urllib2 import urlopen
+try:
+    from openpyxl import Workbook, load_workbook
+    from openpyxl.cell import get_column_letter
+    from openpyxl.shared.exc import InvalidFileException
+    openpyxl_imported = True
+except ImportError:
+    openpyxl_imported = False
 
 
 _DATA_SOURCE = "data"
@@ -110,12 +116,24 @@ class JSONSource(Source):
         Arguments:
             filepath -- the path for the json file.
         """
-        data = json.load(open('%s.json' % filepath, 'r'))
+        json_path = '%s.json' % filepath
+        try:
+            json_file = open(json_path, 'r')
+        except IOError:
+            json_file = open(json_path, 'w')
+            json_file.write("[]")
+            json_file.close()
+            json_file = open(json_path, 'r')
+
+        data = json.load(json_file)
         try:
             elements = dict((element_data[cls.pk_field], element_data)
                             for element_data in data)
         except KeyError:
-            raise AttributeError("Primary key was not found. Check that you have configured the class correctly. In case yopu have check your data source")
+            msg = "Primary key was not found. Check that you have "
+            msg += "configured the class correctly. In case you "
+            msg += "have check your data source"
+            raise AttributeError(msg)
 
         return elements
 
@@ -144,7 +162,9 @@ class YAMLSource(Source):
             for key, value in datos.items():
                 elements[value[cls.pk_field]] = value
         else:
-            raise Exception("In order to use YAML sources you should install the 'PyYAML' package")
+            msg = "In order to use YAML sources you should install "
+            msg += " the 'PyYAML' package"
+            raise Exception(msg)
 
         return elements
 
@@ -153,25 +173,29 @@ class WebServiceSource(Source):
     """Source class for the data stored with JSON format taken through a Web
     Service.
 
-    requires the "request" package to run.
+        Requires the "requests" package to run.
+        http://pypi.python.org/pypi/requests
+
     """
     WSTIMEOUT = 5
 
     def __init__(self, data_path=None, method="get", get_all_cmd="/all",
-                  get_cmd="/data", user=None, password=None, cert=None,
-                  custom_call=None):
+                 get_cmd="/data", user=None, password=None, cert=None,
+                 custom_call=None):
         """Constructor for the WebServiceSource class.
 
         Arguments:
             data_path -- the path where the data is located.
             method -- the http method that will be used witht the web service.
             Defauts to "get".
-            get_all_cmd -- the WS command to fetch all the data. Defaults to "/all".
-            get_cmd -- the WS command to fetch one element. Defaults to "/data"
+            get_all_cmd -- the WS command to fetch all the data.
+            Defaults to "/all".
+            get_cmd -- the WS command to fetch one element.
+            Defaults to "/data"
             user -- the user name for the authentication. If not provided
             the request will not use authentication.
-            password -- the password for the authentication. If not provided the
-            request will not use authentication.
+            password -- the password for the authentication. If not
+            provided the request will not use authentication.
         """
         Source.__init__(self, data_path=data_path)
 
@@ -189,11 +213,13 @@ class WebServiceSource(Source):
             else:
                 self.auth = None
         else:
-            raise Exception("In order to use Web Service sources you should install the 'requests' package")
+            msg = "In order to use Web Service sources you should "
+            msg += " install the 'requests' package"
+            raise Exception(msg)
 
     def read_elements(self, cls, url):
-        """Reads the elements form a WS request. Returns a dictionary containing
-        the read data.
+        """Reads the elements form a WS request. Returns a dictionary
+        containing the read data.
 
         Arguments:
             cls -- the data class.
@@ -241,7 +267,9 @@ class CSVSource(Source):
         """
         data = open('%s.csv' % filepath, 'r')
         keys = data.readline().strip().split(self.separator)
-        dicts = [dict(zip(keys, elem.strip().split(self.separator))) for elem in data]
+        dicts = [dict(zip(keys, elem.strip().split(
+            self.separator))) for elem in data]
+
         try:
             elements = {}
             for element in dicts:
@@ -250,7 +278,10 @@ class CSVSource(Source):
                         del element[key]
                 elements[element[cls.pk_field]] = element
         except KeyError:
-            raise AttributeError("Primary key was not found. Check that you have configured the class correctly. In case yopu have check your data source")
+            msg = "Primary key was not found. Check that you have "
+            msg += "configured the class correctly. In case you "
+            msg += "have check your data source"
+            raise AttributeError(msg)
 
         return elements
 
@@ -267,4 +298,59 @@ class CSVSource(Source):
             lines.append(line + "\n")
 
         data_set.writelines(lines)
-        data_set.close()
\ No newline at end of file
+        data_set.close()
+
+
+class XLSSource(Source):
+    def __init__(self, data_path=None, worksheet=0):
+        Source.__init__(self, data_path=data_path)
+        self.worksheet = worksheet
+
+    """Source class for the data stored with JSON format"""
+    def read_elements(self, cls, filepath):
+        """Reads the elements form a JSON file. Returns a dictionary containing
+        the read data.
+
+        Arguments:
+            filepath -- the path for the json file.
+        """
+        elements = {}
+        if openpyxl_imported:
+            try:
+                wb = load_workbook('%s.xlsx' % filepath)
+                ws = wb.get_active_sheet()
+                rows = list(ws.rows)
+                keys = [row.value for row in rows.pop(0)]
+                for row in rows:
+                    row_dict = {}
+                    for key, cell in enumerate(row):
+                        row_dict[keys[key]] = cell.value
+                    elements[row_dict[cls.pk_field]] = row_dict
+            except InvalidFileException:
+                print("Warning, the file in invalid")
+        else:
+            raise Exception("In order to use XLS sources you should install the 'openpyxl' package")
+
+        return elements
+
+    def write_elements(self, filepath, data):
+        wb = Workbook()
+        dest_filename = '%s.xlsx' % filepath
+        ws = wb.worksheets[self.worksheet]
+        ws.title = "Ojota data"
+
+        keys = []
+        for element in data:
+            keys.extend(element.keys())
+        keys = list(set(keys))
+        row = 1
+        for col_index, key in enumerate(keys, 1):
+            col = get_column_letter(col_index)
+            ws.cell('%s%s'%(col, row)).value = key
+
+        for row, element in enumerate(data, 2):
+            for col_index, key in enumerate(keys, 1):
+                col = get_column_letter(col_index)
+                ws.cell('%s%s'%(col, row)).value = element.get(key)
+
+        wb.save(filename=dest_filename)
